## Geomorph analyses

# 1) Install libraries and load libraries

# install.packages("geomorph")
library(geomorph)
library(abind)

# 2) the path to the classifiers files load sample data and explore

setwd ("~/Desktop/support_appendix")

## ONLY HEAD RSV

##########################################################################################
################### Function: read_tps_write_species_list_classifiers ####################
##########################################################################################

read_tps_write_species_list_classifiers <- function (path_to_tps_value,
                                                     type_picture_value,
                                                     output_directory_value) {

# libraries
require("geomorph")

# user input

path_to_tps <- path_to_tps_value
type_picture <- type_picture_value 
output_directory <- output_directory_value

master_directory <- getwd()

# create and open output dir

dir.create(output_directory, showWarnings = F)
setwd(output_directory)

# get list of tps files

all_tps_files <- list.files(path = path_to_tps, pattern="*.TPS",full.names=T, ignore.case=T)

# read tps files by ID

list_tps <- list ()

for(i in 1:length(all_tps_files)) {
                    list_tps[[i]] <- readland.tps(all_tps_files[i], specID = "ID")
                                  }

# 4) Converting a 3D array into a 2D array (two.d.array). Also, helpful for getting the order of individuals

list_data_tps_2D <- list ()
all_species_factors_list <- list ()
list_species <- list()
list_combined <- list()

for(i in 1:length(list_tps)) {
                species_data_tps_2D <- two.d.array(list_tps[[i]])

                species_rownames <- rownames(species_data_tps_2D)
                species_string_list <- strsplit(species_rownames, "_")
                species_string_df <- as.data.frame(do.call(rbind, species_string_list))

                species_rownames_strings_combined <- cbind(species_rownames, species_string_df, type_picture)
                names(species_rownames_strings_combined) <- c("ID", "genus", "species", "sex",
                                                              "maturity", "museum", "museum_code",
                                                              "country", "locality", "view")

                list_species[[i]] <- paste(species_string_df[1,1],"_", species_string_df[1,2], sep="")
                list_combined[[i]] <- species_rownames_strings_combined
                list_data_tps_2D[[i]] <- species_data_tps_2D

                write.table(species_rownames_strings_combined, file= paste(list_species[[i]],"_", type_picture, "_classifiers.txt", sep=""), sep="\t", row.names =F)
                write.table(rownames(species_data_tps_2D), file= paste(list_species[[i]], "_", type_picture,"_names.txt", sep=""))

                                                      }

# return tps list and 2D arrays

setClass(Class="tps_data",
         representation(
                        tps_list = "list",
                        tps_2D_list="list"
          ))

# return to working directoy and return list

setwd(master_directory)

return(list(
            tps_list=list_tps,
            tps_2D_list = list_data_tps_2D
            ))

                                                   }

#############################          end of function         ############################

# HEAD: RSV

RSV_tps_2D_list <- read_tps_write_species_list_classifiers (path_to_tps_value = "~/Desktop/support_appendix/per_species_RSV",
                                                     type_picture_value = "rsv",
                                                     output_directory_value = "~/Desktop/support_appendix/all_species_classifiers")

##########################################################################################
######################### Function: read_classifiers_as_df    ############################
##########################################################################################


read_classifiers_as_df <- function (path_to_classifiers_value,
                                           type_picture_value) {

# user input

path_to_classifiers <- path_to_classifiers_value
type_picture <- type_picture_value 

## list files of species

list_species_sampled <- list.files(path = path_to_classifiers, pattern="*.txt$",full.names=T, ignore.case=T)
all_species_classifiers <- grep(pattern = paste(type_picture, "_classifiers", sep ="") , list_species_sampled, value=TRUE)

# separate to classifier list and species ID lists

all_species_classifiers_list <- list ()

for(i in 1:length(all_species_classifiers)) {
                        all_species_classifiers_list[[i]] <- read.table(file = all_species_classifiers[i], header=TRUE, sep="\t")
                                            }

## read files and place those in separate lists

return(all_species_classifiers_list)

}

#############################          end of function         ############################

# RSV classifiers

RSV_classifier_list <- read_classifiers_as_df (path_to_classifiers_value = "~/Desktop/support_appendix/all_species_classifiers",
                                                      type_picture_value = "rsv")


##########################################################################################
################# Function: get_geomorphometric_sex_dimorphism_analyses  #################
##########################################################################################

# mag_number is for mag of the function 'plotRefToTarget' from geomorph
# This mag-number is the desired magnification to be used when visualizing the shape difference (e.g., mag=2)

get_geomorphometric_sex_dimorphism_analyses <- function (species_tps_list_value, 
                                                         species_classifier_list_value,
                                                         mag_number_value = 0.9,
                                                         output_directory_value) {

# input from user

species_tps_list <- species_tps_list_value$tps_list
species_classifier_list <- species_classifier_list_value
mag_number <- mag_number_value
output_directory <- output_directory_value

master_directory <- getwd()

# create and open output dir

dir.create(output_directory, showWarnings = F)
setwd(output_directory)

##############           for each species in a loop

## select species to analyse

for( i in 1:length(species_classifier_list_value)) {

one_species_tps <- species_tps_list[[i]]
one_species_classifiers <- species_classifier_list[[i]]

# give to user

cat("---------- processing species: ", paste0(one_species_classifiers$genus[1], "_", one_species_classifiers$species[1]), "    \n")

###### Elimnate juveniles

maturity_character <- as.character(one_species_classifiers$maturity)
species_sex <- one_species_classifiers$sex
sex_species_adults <- species_sex[!maturity_character == "j"]

maturity_df <- as.data.frame(maturity_character)
rows_with_j<- which(grepl("j", maturity_df$maturity_character))
species_tps_adults <- if(!length(rows_with_j)) {
                                                species_tps_adults <- one_species_tps
                                            } else { species_tps_adults <- one_species_tps[,,-rows_with_j]}

# split tps by sex

species_tps_adults_names <- dimnames(species_tps_adults)[[3]]
species_tps_adults_names_list <-  strsplit(species_tps_adults_names, "_")
species_tps_adults_names_df <- as.data.frame(do.call(rbind, species_tps_adults_names_list))
names(species_tps_adults_names_df) <- c("genus", "species", "sex",
                                                              "maturity", "museum", "museum_code",
                                                              "country", "locality")
species_tps_adults_names_df$genus_species <- as.factor(paste(species_tps_adults_names_df$genus, "_", species_tps_adults_names_df$species, sep=""))

sex_character <- as.character(species_tps_adults_names_df$sex)
sex_df <- as.data.frame(sex_character)
male_with_m<- which(grepl("m", sex_df$sex_character))
male_tps_adults <- species_tps_adults[,,male_with_m]
female_tps_adults <- species_tps_adults[,,-male_with_m]

# pass from tps to 2D array and dor gpagen

species_data_tps_2D_adults <- two.d.array(species_tps_adults)
species_gpagen_adult <- gpagen(species_tps_adults, print.progress = FALSE)

# Males & Females: gpagen

male_gpagen_adult <- gpagen(male_tps_adults, print.progress = FALSE)
female_gpagen_adult <- gpagen(female_tps_adults, print.progress = FALSE)

# Pre-Plot reference to target

ref_males<-mshape(male_gpagen_adult$coords)
ref_females<-mshape(female_gpagen_adult$coords)

# The function returns a list containing the Procrustes coordinates ($coords), 
# The centroid sizes ($Csize) and,
# if ShowPlot=T, a graph of the specimens (grey) around the mean (black) shape

#### Covariation methods: Procrustes ANOVA/regression for shape data (procD.lm)

## species to 2D array

species_data_gpagen_2D_adult_coord<-two.d.array(species_gpagen_adult$coords) # need a 2D array of coordinates after GPA

############     preparing data

Y.gpa <- species_gpagen_adult
gdf <- geomorph.data.frame(Y.gpa, sex = sex_species_adults)

male_gdf <- geomorph.data.frame(male_gpagen_adult)
female_gdf <- geomorph.data.frame(female_gpagen_adult)

################           Procrustes ANOVA/regression for shape data

species_procD_lm_results <- procD.lm(coords~sex_species_adults,iter=999, data=gdf, verbose = T, RRPP = TRUE, print.progress = FALSE)
out_procD_lm_sex_no_allometry <- summary(species_procD_lm_results)

################################       procustes by allometry  by sex     ################

species_procD_lm_results_allometry <- procD.allometry(coords~Csize, f2 = ~sex_species_adults, f3=NULL, logsz = TRUE, data=gdf, iter=999, print.progress = FALSE)
out_procD_lm_sex_allometry <- summary(species_procD_lm_results_allometry)

species_procD_lm_results_male <- try(procD.lm(coords ~ Csize, data = male_gdf, iter = 999, RRPP = TRUE, print.progress = FALSE), silent = TRUE)

if(class(species_procD_lm_results_male) == "try-error") {
                              out_procD_lm_male_allometry <- "not enough males"
                                                        } else {
                              out_procD_lm_male_allometry <- summary(species_procD_lm_results_male)
                                                        }

species_procD_lm_results_female <- procD.lm(coords ~ Csize, data = female_gdf, iter = 999, RRPP = TRUE, print.progress = FALSE)
out_procD_lm_female_allometry <- summary(species_procD_lm_results_female)

################         Morphological disparity              ############################

# For the entire data set

disparity_among_all_specimens_in_species <- morphol.disparity(coords ~ 1, groups= NULL, data = gdf, iter=999, print.progress = FALSE)
disparity_among_male_specimens_in_species_raw <- try(morphol.disparity(coords ~ 1, groups= NULL, data = male_gdf, iter=999, print.progress = FALSE))

if(class(disparity_among_male_specimens_in_species_raw) == "try-error") {
                              disparity_among_male_specimens_in_species <- "not enough males"
                                                        } else {
                              disparity_among_male_specimens_in_species <- disparity_among_male_specimens_in_species_raw
                                                        }

disparity_among_female_specimens_in_species <- morphol.disparity(coords ~ 1, groups= NULL, data = female_gdf, iter=999, print.progress = FALSE)

# Morphological disparity for entire data set, accounting for allometry

disparity_among_allometry_all_specimens_in_species <- morphol.disparity(coords ~ Csize, groups= NULL, data = gdf, iter=999, print.progress = FALSE)
disparity_among_allometry_male_specimens_in_species_raw <- try(morphol.disparity(coords ~ Csize, groups= NULL, data = male_gdf, iter=999, print.progress = FALSE))

if(class(disparity_among_allometry_male_specimens_in_species_raw) == "try-error") {
                              disparity_among_allometry_male_specimens_in_species <- "not enough males"
                                                        } else {
                              disparity_among_allometry_male_specimens_in_species <- disparity_among_allometry_male_specimens_in_species_raw
                                                        }

disparity_among_allometry_female_specimens_in_species <- morphol.disparity(coords ~ Csize, groups= NULL, data = female_gdf, iter=999, print.progress = FALSE)


# Morphological disparity without covariates, using overall mean

disparity_by_sex_species_overall_mean <- morphol.disparity(coords ~ 1, groups= ~ sex_species_adults, data = gdf, iter=999, print.progress = FALSE)

# Morphological disparity without covariates, using overall mean, accounting for allometry

disparity_by_sex_species_overall_mean_allometry <- morphol.disparity(coords ~ Csize, groups= ~ sex_species_adults, data = gdf, iter=999, print.progress = FALSE)

# Morphological disparity without covariates, using group means

disparity_by_sex_species_group_mean <-  morphol.disparity(coords ~ sex_species_adults, groups= ~sex_species_adults, data = gdf, iter=999, print.progress = FALSE)

# Morphological disparity without covariates, using group means, accounting for allometry

disparity_by_sex_species_group_mean_allometry <-  morphol.disparity(coords ~ Csize*sex_species_adults, groups= ~sex_species_adults, data = gdf, iter=999, print.progress = FALSE)

## species name

species_name <- paste(as.character(one_species_classifiers$genus[1]), "_", as.character(one_species_classifiers$species[1]), sep="")
n_males <- nrow(subset(one_species_classifiers, sex == "m"))
n_females <- nrow(subset(one_species_classifiers, sex == "f"))
type_view <- as.character(one_species_classifiers$view[1])

### output files to user

writeLines(capture.output( {

cat("=============================\n")
cat("Species \n")
cat("=============================\n")
cat("\n")
print(paste("species code: ",species_name, sep=""))
cat("\n")
print(paste("number of males: ", n_males, sep=""))
cat("\n")
print(paste("number of females: ", n_females, sep=""))
cat("\n")
cat("=============================\n")
cat("Procrustes ANOVA/regression for shape data for sex no allometry \n")
cat("=============================\n")
cat("\n")
print(out_procD_lm_sex_no_allometry)
cat("\n")
cat("=============================\n")
cat("Procrustes ANOVA/regression for shape data for sex by allometry \n")
cat("=============================\n")
cat("\n")
print(out_procD_lm_sex_allometry)
cat("\n")
cat("=============================\n")
cat("Procrustes ANOVA/regression for shape data for males by allometry \n")
cat("=============================\n")
cat("\n")
print(out_procD_lm_male_allometry)
cat("\n")
cat("=============================\n")
cat("Procrustes ANOVA/regression for shape data for females by allometry \n")
cat("=============================\n")
cat("\n")
print(out_procD_lm_female_allometry)
cat("\n")
cat("=============================\n")
cat("Morphological disparity by sex \n")
cat("=============================\n")
cat("\n")
cat("Morphological disparity 'morphol.disparity' function estimates morphological disparity and performs pairwise comparisons among groups \n")
cat("\n")
cat("=============================\n")
cat("Morphological disparity among all_specimens in species \n")
cat("=============================\n")
cat("\n")
print(disparity_among_all_specimens_in_species)
cat("\n")
cat("=============================\n")
cat("Morphological disparity among all_specimens in species - ONLY MALES \n")
cat("=============================\n")
cat("\n")
print(disparity_among_male_specimens_in_species)
cat("\n")
cat("=============================\n")
cat("Morphological disparity among all_specimens in species - ONLY FEMALES \n")
cat("=============================\n")
cat("\n")
print(disparity_among_female_specimens_in_species)
cat("\n")
cat("=============================\n")
cat("Morphological disparity for entire data set, accounting for allometry \n")
cat("=============================\n")
cat("\n")
print(disparity_among_allometry_all_specimens_in_species)
cat("\n")
cat("=============================\n")
cat("Morphological disparity for entire data set, accounting for allometry - ONLY MALES \n")
cat("=============================\n")
cat("\n")
print(disparity_among_allometry_male_specimens_in_species)
cat("\n")
cat("=============================\n")
cat("Morphological disparity for entire data set, accounting for allometry - ONLY FEMALES \n")
cat("=============================\n")
cat("\n")
print(disparity_among_allometry_female_specimens_in_species)
cat("\n")
cat("=============================\n")
cat("Morphological disparity without covariates, using overall mean by sex \n")
cat("=============================\n")
cat("\n")
print(disparity_by_sex_species_overall_mean)
cat("\n")
cat("=============================\n")
cat("Morphological disparity without covariates, using overall mean by sex, accounting for allometry \n")
cat("=============================\n")
cat("\n")
print(disparity_by_sex_species_overall_mean_allometry)
cat("\n")
cat("=============================\n")
cat("Morphological disparity without covariates, using group means \n")
cat("=============================\n")
cat("\n")
print(disparity_by_sex_species_group_mean)
cat("\n")
cat("=============================\n")
cat("Morphological disparity without covariates, using group means, accounting for allometry \n")
cat("=============================\n")
cat("\n")
print(disparity_by_sex_species_group_mean_allometry)
cat("\n")

     } ),con=paste0(species_name,"_",type_view,"_per_species_sex_diff_geomorphology_out.txt"))

## print image

pdf(paste(species_name,"_",type_view,"_per_species_sex.pdf", sep=""))
plotAllSpecimens(Y.gpa$coord)
title(main="all_specimens")
plotAllSpecimens(male_gpagen_adult$coord)
title(main="males_specimens")
plotAllSpecimens(female_gpagen_adult$coord)
title(main="female_specimens")
plot(species_procD_lm_results, method = "PredLine")
title(main="procD_lm_results_PredLine")
plot(species_procD_lm_results_allometry, method = "PredLine")
title(main="procD_lm_allometry_results_PredLine")
plotRefToTarget(ref_females, ref_males) # reference is males
title(main="Shape differences with reference to males")
plotRefToTarget(ref_females, ref_males,method="vector",mag=mag_number) # reference is males
title(main="Shape differences with reference to females")
dev.off()
                          } # end loop i
rm(i)
setwd(master_directory)

}

#############################          end of function         ############################


# RSV analyses by sex by individual species

get_geomorphometric_sex_dimorphism_analyses (species_tps_list_value = RSV_tps_2D_list, 
                                                         species_classifier_list_value = RSV_classifier_list,
                                                         mag_number_value = 0.9,
                                                         output_directory_value = "~/Desktop/support_appendix/non_phylogenetic_geomorphometric")

##########################################################################################
#################            Function: get_geomorph_species_means                 #################
##########################################################################################

get_geomorph_species_means <- function (species_tps_list_value,
                                        species_classifier_list_value) {

# input from user

species_tps_list <- species_tps_list_value$tps_list
species_classifier_list <- species_classifier_list_value

##############           for each species in a loop

tps_males_list <- list()
tps_females_list <- list()
species_list <- list()

for (i in 1:length(species_classifier_list)) {

## each species

one_species_tps <- species_tps_list[[i]]
one_species_classifiers <- species_classifier_list[[i]]

# one_species_tps <- species_tps_list[[8]]
# one_species_classifiers <- species_classifier_list[[8]]

###### Elimnate juveniles

maturity_character <- as.character(one_species_classifiers$maturity)
species_sex <- one_species_classifiers$sex
sex_species_adults <- species_sex[!maturity_character == "j"]

maturity_df <- as.data.frame(maturity_character)
rows_with_j<- which(grepl("j", maturity_df$maturity_character))
species_tps_adults <- if(!length(rows_with_j)) {
                                                species_tps_adults <- one_species_tps
                                            } else { species_tps_adults <- one_species_tps[,,-rows_with_j]}

# split tps by sex

species_tps_adults_names <- dimnames(species_tps_adults)[[3]]
species_tps_adults_names_list <-  strsplit(species_tps_adults_names, "_")
species_tps_adults_names_df <- as.data.frame(do.call(rbind, species_tps_adults_names_list))
names(species_tps_adults_names_df) <- c("genus", "species", "sex",
                                                              "maturity", "museum", "museum_code",
                                                              "country", "locality")
species_tps_adults_names_df$genus_species <- as.factor(paste(species_tps_adults_names_df$genus, "_", species_tps_adults_names_df$species, sep=""))

sex_character <- as.character(species_tps_adults_names_df$sex)
sex_df <- as.data.frame(sex_character)
male_with_m<- which(grepl("m", sex_df$sex_character))
male_tps_adults <- species_tps_adults[,,male_with_m]
female_tps_adults <- species_tps_adults[,,-male_with_m]

### get means

male_tps_adults_mean <- mshape(male_tps_adults)
female_tps_adults_mean <- mshape(female_tps_adults)

## get species name

one_species_name <- paste0(one_species_classifiers$genus[1], "_", one_species_classifiers$species[1])

## put all in three list

tps_males_list[[i]] <- male_tps_adults_mean
tps_females_list[[i]] <- female_tps_adults_mean
species_list[[i]] <- one_species_name

                                                  }

##############           END: for each species in a loop

## append arrays with species names name to array

species_name_vector <- c(do.call("rbind",species_list)) 

# males
male_species_combined_tps_raw <- abind(tps_males_list, along=3)
dimnames(male_species_combined_tps_raw)[3] <- list(species_name_vector)

# females
female_species_combined_tps_raw <- abind(tps_females_list, along=3)
dimnames(female_species_combined_tps_raw)[3] <- list(species_name_vector)

########## create a list to return

male_female_list <- list(males = male_species_combined_tps_raw, females = female_species_combined_tps_raw)

return(male_female_list)

}

#############################          end of function         ############################

# RSV classifiers

species_means_landmarks_array_list <- get_geomorph_species_means (species_tps_list_value <- RSV_tps_2D_list,
                                                                  species_classifier_list_value <- RSV_classifier_list)

##########################################################################################
################# Function: prepare phylogeny  #################
##########################################################################################

corytophanidae_tree <- read.tree(file = "~/Desktop/support_appendix/Coryto_renamed_TPC_Fig_1_chrono_tree_newick.newick")

##########################################################################################
################# Function: get_geomorphometric_phylogenetic  #################
##########################################################################################

get_phylogenetic_geomorphometric_analyses_by_sex <- function (landmarks_array_males_value, 
                                                              landmarks_array_females_value,
                                                              disparity_between_species_value,
                                                              disparity_between_landmarks_value,
                                                              phylogeny_value,
                                                              file_label_value) {

# input from user

landmarks_males_array <- landmarks_array_males_value
landmarks_females_array <- landmarks_array_females_value
phylogeny <- phylogeny_value

disparity_between_species <- factor(disparity_between_species_value)
names(disparity_between_species)<-phylogeny$tip

disparity_between_landmarks <- disparity_between_landmarks_value

file_label <- file_label_value

############################            males            #################################

### Generalized Procrustes analysis of points, curves, and surfaces

landmarks_males_gpa<-gpagen(landmarks_males_array)

### physignal
## Test for phylogenetic signal in shape: coords

males_clade_physignal_coords <- physignal(A=landmarks_males_gpa$coords,phy=phylogeny,iter=999)
males_clade_physignal_coords_sum <- summary(males_clade_physignal_coords)

### physignal
## Test for phylogenetic signal in size: $Csize

males_clade_physignal_Csize <- physignal(A=landmarks_males_gpa$Csize,phy=phylogeny,iter=999)
males_clade_physignal_Csize_sum <- summary(males_clade_physignal_Csize)

## compare evolutionary rates between species

ER_males <-compare.evol.rates(A=landmarks_males_gpa$coords, phy=phylogeny,gp=disparity_between_species,iter=999)
ER_males_summary <- summary(ER_males)

## compare evolutionary rates between landmarks

EMR_males <- compare.multi.evol.rates(A=landmarks_males_gpa$coords,gp=disparity_between_landmarks, Subset=TRUE, phy= phylogeny,iter=999)
EMR_males_summary <- summary(EMR_males)

## compare phylogenetic integration between landmarks

Phylo_integration_males <- phylo.integration(A = landmarks_males_gpa$coords, partition.gp = disparity_between_landmarks, phy=phylogeny,iter=999)
Phylo_integration_males_summary <- summary(Phylo_integration_males)

## compare phylogenetic modularity between landmarks

Phylo_modularity_males <- phylo.modularity(A = landmarks_males_gpa$coords, partition.gp = disparity_between_landmarks, phy=phylogeny,iter=999)
Phylo_modularity_males_summary <- summary(Phylo_modularity_males)

### D-PGLS for high-dimensional data

gdf_males <- geomorph.data.frame(landmarks_males_gpa, phy = phylogeny)
procD.pgls_males_RRPP_F <- procD.pgls(coords ~ Csize, phy = phy, data = gdf_males, iter = 999, RRPP = FALSE) # randomize raw values
procD.pgls_males_RRPP_F_sum <- summary(procD.pgls_males_RRPP_F)
procD.pgls_males_RRPP_T <- procD.pgls(coords ~ Csize, phy = phy, data = gdf_males, iter = 999, RRPP = TRUE) # randomize residuals
procD.pgls_males_RRPP_T_sum <- summary(procD.pgls_males_RRPP_T)

## plot figure

pdf(paste0(file_label_value, "_males_plotGMPhyloMorphoSpace.pdf"))
plotGMPhyloMorphoSpace(phylogeny,landmarks_males_gpa$coords, plot.param=list(t.bg="blue",txt.col="red",n.cex=1))
dev.off()

############################            females            #################################

### Generalized Procrustes analysis of points, curves, and surfaces

landmarks_females_gpa<-gpagen(landmarks_females_array)

### physignal
## Test for phylogenetic signal in shape: coords

females_clade_physignal_coords <- physignal(A=landmarks_females_gpa$coords,phy=phylogeny,iter=999)
females_clade_physignal_coords_sum <- summary(females_clade_physignal_coords)

### physignal
## Test for phylogenetic signal in size: $Csize

females_clade_physignal_Csize <- physignal(A=landmarks_females_gpa$Csize,phy=phylogeny,iter=999)
females_clade_physignal_Csize_sum <- summary(females_clade_physignal_Csize)

## compare evolutionary rates between species

ER_females <-compare.evol.rates(A=landmarks_females_gpa$coords, phy=phylogeny,gp=disparity_between_species,iter=999)
ER_females_summary <- summary(ER_females)

## compare evolutionary rates between landmarks

EMR_females <- compare.multi.evol.rates(A=landmarks_females_gpa$coords,gp=disparity_between_landmarks, Subset=TRUE, phy= phylogeny,iter=999)
EMR_females_summary <- summary(EMR_females)

## compare phylogenetic integration between landmarks

Phylo_integration_females <- phylo.integration(A = landmarks_females_gpa$coords, partition.gp = disparity_between_landmarks, phy=phylogeny,iter=999)
Phylo_integration_females_summary <- summary(Phylo_integration_females)

## compare phylogenetic modularity between landmarks

Phylo_modularity_females <- phylo.modularity(A = landmarks_females_gpa$coords, partition.gp = disparity_between_landmarks, phy=phylogeny,iter=999)
Phylo_modularity_females_summary <- summary(Phylo_modularity_females)

### Example of D-PGLS for high-dimensional data

gdf_females <- geomorph.data.frame(landmarks_females_gpa, phy = phylogeny)
procD.pgls_females_RRPP_F <- procD.pgls(coords ~ Csize, phy = phy, data = gdf_females, iter = 999, RRPP = FALSE) # randomize raw values
procD.pgls_females_RRPP_F_sum <- summary(procD.pgls_females_RRPP_F)
procD.pgls_females_RRPP_T <- procD.pgls(coords ~ Csize, phy = phy, data = gdf_females, iter = 999, RRPP = TRUE) # randomize residuals
procD.pgls_females_RRPP_T_sum <- summary(procD.pgls_females_RRPP_T)

## plot figure

pdf(paste0(file_label_value, "_females_plotGMPhyloMorphoSpace.pdf"))
plotGMPhyloMorphoSpace(phylogeny,landmarks_females_gpa$coords, plot.param=list(t.bg="blue",txt.col="red",n.cex=1))
dev.off()

############################            males and females           #################################


phylo_integration_males_females <- phylo.integration(A = landmarks_males_gpa$coords, A2 = landmarks_females_gpa$coords ,phy=phylogeny,iter=999)
phylo_integration_males_females_sum <- summary(phylo_integration_males_females)

############################              summaries to text               ################

writeLines(capture.output( {
                          cat("------------                          Males                          ------------\n")
                          cat("------------      Test for phylogenetic signal in shape: coords      ------------\n\n")
                          print(males_clade_physignal_coords_sum)
                          cat("\n")
                          cat("------------      Test for phylogenetic signal in size: $Csize      ------------\n\n")
                          print(males_clade_physignal_Csize_sum)
                          cat("\n")
                          cat("------------      compare evolutionary rates between species      ------------\n\n")
                          print(ER_males_summary)
                          cat("\n")
                          cat("------------      compare evolutionary rates between landmarks      ------------\n\n")
                          print(EMR_males_summary)
                          cat("\n")
                          cat("------------      compare phylogenetic integration between landmarks      ------------\n\n")
                          print(Phylo_integration_males_summary)
                          cat("\n")
                          cat("------------      compare phylogenetic modularity between landmarks      ------------\n\n")
                          print(Phylo_modularity_males_summary)
                          cat("\n")
                          cat("------------      D-PGLS for high-dimensional data      ------------\n\n")
                          print(procD.pgls_males_RRPP_F_sum)
                          cat("\n")
                          print(procD.pgls_males_RRPP_T_sum)
                          cat("\n")
                          cat("------------                          Females                          ------------\n")
                          cat("------------      Test for phylogenetic signal in shape: coords      ------------\n\n")
                          print(females_clade_physignal_coords_sum)
                          cat("\n")
                          cat("------------      Test for phylogenetic signal in size: $Csize      ------------\n\n")
                          print(females_clade_physignal_Csize_sum)
                          cat("\n")
                          cat("------------      compare evolutionary rates between species      ------------\n\n")
                          print(ER_females_summary)
                          cat("\n")
                          cat("------------      compare evolutionary rates between landmarks      ------------\n\n")
                          print(EMR_females_summary)
                          cat("\n")
                          cat("------------      compare phylogenetic integration between landmarks      ------------\n\n")
                          print(Phylo_integration_females_summary)
                          cat("\n")
                          cat("------------      compare phylogenetic modularity between landmarks      ------------\n\n")
                          print(Phylo_modularity_females_summary)
                          cat("\n")
                          cat("------------      D-PGLS for high-dimensional data      ------------\n\n")
                          print(procD.pgls_females_RRPP_F_sum)
                          cat("\n")
                          print(procD.pgls_females_RRPP_T_sum)
                          cat("\n")
                          cat("------------                       Males and Females                          ------------\n")
                          cat("------------      compare phylogenetic integration between landmarks      ------------\n\n")
                          print(phylo_integration_males_females_sum)
                          cat("\n")
                          cat("-----------------------------------------------------------\n\n")
                                 }
                                      ),con=paste0(file_label, "_phylogenetic_geomorphometrics_analyses.txt"))

                                              }

###########################            END of Function          ##########################



get_phylogenetic_geomorphometric_analyses_by_sex (landmarks_array_males_value = species_means_landmarks_array_list$males, 
                                                  landmarks_array_females_value = species_means_landmarks_array_list$females,
                                                  disparity_between_species_value = c(1,1,1,1,0,0,0,0,0),
                                                  disparity_between_landmarks_value = c("N","N","N","N",
                                                                                        "N","N","N","N",
                                                                                        "C","C","C","C"),
                                                              phylogeny_value = corytophanidae_tree,
                                                              file_label_value = "Corytophanidae")

# strong crest dimorphism: 0 or 1
# bas_bas: 1, bas_gal: 1, bas_plu: 1, bas_vit: 1, cor_cri: 0, cor_her: 0, cor_per: 0, lae_lon: 0, lae_ser: 0
# disparity_between_species_value <- c(1,1,1,1,0,0,0,0,0)

# compare rates between landmarks
# disparity between crest landmarks and rest
# disparity_between_landmarks_value <- c("N","N","N","N",
#                                         "N","N","N","N",
#                                         "C","C","C","C")


# landmarks_array_males_value <- species_means_landmarks_array_list$males
# landmarks_array_females_value <- species_means_landmarks_array_list$females
# disparity_between_species_value <- c(1,1,1,1,0,0,0,0,0)
# disparity_between_landmarks_value <- c("N","N","N","N",
#                                         "N","N","N","N",
#                                         "C","C","C","C")
# phylogeny_value <- corytophanidae_tree
# file_label_value <- "Corytophanidae"

